ProSHADE: Member List

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

ProSHADE_internal_spheres::ProSHADE_rotFun_sphere Member List

This is the complete list of members for ProSHADE_internal_spheres::ProSHADE_rotFun_sphere, including all inherited members.

findAllPeaks(proshade_signed noSmNeighbours, std::vector< proshade_double > *allHeights) | ProSHADE_internal_spheres::ProSHADE_rotFun_sphere |
getAngularDim(void) | ProSHADE_internal_spheres::ProSHADE_rotFun_sphere |
getMaxRadius(void) | ProSHADE_internal_spheres::ProSHADE_rotFun_sphere |
getMinRadius(void) | ProSHADE_internal_spheres::ProSHADE_rotFun_sphere |
getPeaks(void) | ProSHADE_internal_spheres::ProSHADE_rotFun_sphere |
getRadius(void) | ProSHADE_internal_spheres::ProSHADE_rotFun_sphere |
getRepresentedAngle(void) | ProSHADE_internal_spheres::ProSHADE_rotFun_sphere |
getSphereLatLonLinearInterpolationPos(proshade_double lattitude, proshade_double longitude) | ProSHADE_internal_spheres::ProSHADE_rotFun_sphere |
getSphereLatLonPosition(proshade_unsign lattitude, proshade_unsign longitude) | ProSHADE_internal_spheres::ProSHADE_rotFun_sphere |
getSphereNumber(void) | ProSHADE_internal_spheres::ProSHADE_rotFun_sphere |
interpolateSphereValues(proshade_complex *rotFun) | ProSHADE_internal_spheres::ProSHADE_rotFun_sphere |
ProSHADE_rotFun_sphere(proshade_double rad, proshade_double radRange, proshade_unsign dim, proshade_double repAng, proshade_unsign sphNo) | ProSHADE_internal_spheres::ProSHADE_rotFun_sphere |
removeSmallPeaks(proshade_double peakThres) | ProSHADE_internal_spheres::ProSHADE_rotFun_sphere |
~ProSHADE_rotFun_sphere(void) | ProSHADE_internal_spheres::ProSHADE_rotFun_sphere |